summaryrefslogtreecommitdiffstats
path: root/kig/objects/object_imp_factory.h
diff options
context:
space:
mode:
Diffstat (limited to 'kig/objects/object_imp_factory.h')
-rw-r--r--kig/objects/object_imp_factory.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kig/objects/object_imp_factory.h b/kig/objects/object_imp_factory.h
index 1ac08dde..6056f45d 100644
--- a/kig/objects/object_imp_factory.h
+++ b/kig/objects/object_imp_factory.h
@@ -27,14 +27,14 @@ class ObjectImpFactory
public:
static const ObjectImpFactory* instance();
/**
* loads data from \p parent , and returns a new ObjectImp from the type
* string \p type .
*/
- ObjectImp* deserialize( const TQString& type, const TQDomElement& parent, TQString& error ) const;
+ ObjectImp* deserialize( const TQString& type, const TQDomElement& tqparent, TQString& error ) const;
/**
* adds data to \p parent , and returns a type string..
*/
- TQString serialize( const ObjectImp& d, TQDomElement& parent, TQDomDocument& doc ) const;
+ TQString serialize( const ObjectImp& d, TQDomElement& tqparent, TQDomDocument& doc ) const;
};
#endif
@@ -27,14 +27,14 @@ class ObjectImpFactory
static const ObjectImpFactory* instance();
/**
- * loads data from \p parent , and returns a new ObjectImp from the type
+ * loads data from \p tqparent , and returns a new ObjectImp from the type
* string \p type .
*/
@@ -27,14 +27,14 @@ class ObjectImpFactory
/**
- * adds data to \p parent , and returns a type string..
+ * adds data to \p tqparent , and returns a type string..
*/